<?php
require_once '../config/Database.php'; 
require_once '../models/GraficoModel.php';

header('Content-Type: application/json'); // Aseguramos que siempre se devuelva JSON

if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    $input = json_decode(file_get_contents('php://input'), true);
    $tipoConsulta = $input['tipoConsulta'] ?? '';
  
    
  
    switch ($tipoConsulta) {
        case 'Femenino':
            $cantidad = GraficoModel::obtenerGeneroFemenino();
            break;
        case 'Masculino':
            $cantidad = GraficoModel::obtenerGeneroMasculino();
            break;
        case 'Prefiero no decirlo':
            $cantidad = GraficoModel::obtenerGeneroNoDefinido();
            break;
        case 'Menor de 18 años':
            $cantidad = GraficoModel::obtenerEdadMenor18();
            break;
        case '18 a 24 años':
            $cantidad = GraficoModel::obtenerEdad1824();
            break;
        case '25 a 34 años':
            $cantidad = GraficoModel::obtenerEdad2434();
            break;
        case '35 a 44 años':
            $cantidad = GraficoModel::obtenerEdad3544();
            break;
        case '45 a 54 años':
            $cantidad = GraficoModel::obtenerEdad4554();
            break;
        case '55 a 64 años':
            $cantidad = GraficoModel::obtenerEdad5564();
            break;
        case '65 años o más':
            $cantidad = GraficoModel::obtenerEdad65oMas();
            break;
        case 'Estados':
          $cantidad = GraficoModel::obtenerEstados();
          echo json_encode($cantidad); // Devolver directamente el array de estados
          exit; // Terminar la ejecucion aqui
        case 'Examenes':
          $cantidad = GraficoModel::obtenerExamenes();
          echo json_encode($cantidad); // Devolver directamente el array de examenes
          exit; // Terminar la ejecucion aqui
        default:
            $cantidad = 0;
    }
  
    echo json_encode(['cantidad' => $cantidad]);
  }

?>